@@ -1,3 +1,9 @@
+def hz_to_normalized_rad(freqs, fs):
+    return freqs / fs * 2 * np.pi
+
+def normalized_rad_to_hz(rad, fs):
+    return rad / np.pi * fs / 2
+
 # @pre.standardize_asa(x='data', fs='fs', n_signals=1, 
 #                         class_method=False, abscissa_vals='timestamps')
 def cwt(data, *, timestamps=None, fs=1, wavelet=MorseWavelet(gamma=3, beta=20),
